﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Net.Browser;
using System.IO;
using System.Windows.Media;

namespace SilverlightApplication111
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
        }

        // same domain call
        private void SameDomainBrowserStack(object sender, RoutedEventArgs e)
        {
            WebClient c = new WebClient();
            c.Headers[HttpRequestHeader.Authorization] = "Auth header from same domain-browser stack";
            c.DownloadStringCompleted += ((s, args) =>
                {
                    if (args.Error != null)
                    {
                        response.Text = args.Error.Message;
                        response.Foreground = new SolidColorBrush(Colors.Red);
                    }
                    response.Text = args.Result;
                });
            c.DownloadStringAsync(new Uri("http://localhost:4469/handler.ashx"));
        }

        private void SameDomainBrowserStack2(object sender, RoutedEventArgs e)
        {
            HttpWebRequest req = (HttpWebRequest)WebRequest.CreateHttp("http://localhost:4469/handler.ashx");
            req.Headers[HttpRequestHeader.Authorization] = "Auth header from same domain using HWR";
            req.BeginGetResponse((cb) =>
                {
                    HttpWebRequest rq = cb.AsyncState as HttpWebRequest;
                    HttpWebResponse resp = rq.EndGetResponse(cb) as HttpWebResponse;

                    StreamReader rdr = new StreamReader(resp.GetResponseStream());
                    string foo = rdr.ReadToEnd();
                    Dispatcher.BeginInvoke(() =>
                        {
                            response.Text = foo;
                        });
                    rdr.Close();

                }, req);
        }


        // x-domain call no clienthttp
        private void CrossDomainBrowserStack(object sender, RoutedEventArgs e)
        {
            WebClient c = new WebClient();
            c.Headers[HttpRequestHeader.Authorization] = "Auth header from x-domain no client";
            c.DownloadStringCompleted += ((s, args) =>
            {
                if (args.Error != null)
                {
                    response2.Text = args.Error.Message;
                    response2.Foreground = new SolidColorBrush(Colors.Red);
                }
                else
                {
                    response2.Text = args.Result;
                }
            });
            c.DownloadStringAsync(new Uri("http://localhost:6082/handler.ashx"));
        }

        // x-domain call clienthttp
        private void CrossDomainClientStack(object sender, RoutedEventArgs e)
        {
            WebRequest.RegisterPrefix("http://", WebRequestCreator.ClientHttp);

            WebClient c = new WebClient();
            c.Headers[HttpRequestHeader.Authorization] = "Auth header from x-domain client";
            c.DownloadStringCompleted += ((s, args) =>
            {
                if (args.Error != null)
                {
                    response3.Text = args.Error.Message;
                    response3.Foreground = new SolidColorBrush(Colors.Red);
                }
                else
                {
                    response3.Text = args.Result;
                }
            });
            c.DownloadStringAsync(new Uri("http://localhost:6082/handler.ashx"));
        }

        private void SameDomainClientStack(object sender, RoutedEventArgs e)
        {
            WebRequest.RegisterPrefix("http://", WebRequestCreator.ClientHttp);

            WebClient c = new WebClient();
            c.Headers[HttpRequestHeader.Authorization] = "Auth header from same domain-clientstack";
            c.DownloadStringCompleted += ((s, args) =>
            {
                if (args.Error != null)
                {
                    response4.Text = args.Error.Message;
                    response4.Foreground = new SolidColorBrush(Colors.Red);
                }
                response4.Text = args.Result;
            });
            c.DownloadStringAsync(new Uri("http://localhost:4469/handler.ashx"));
        }

        private void CrossDomainBrowserStackNoPolicy(object sender, RoutedEventArgs e)
        {
            WebClient c = new WebClient();
            c.Headers[HttpRequestHeader.Authorization] = "Auth header from x-domain browser-no policy";
            c.DownloadStringCompleted += ((s, args) =>
            {
                if (args.Error != null)
                {
                    response5.Text = args.Error.InnerException.Message;
                    response5.Foreground = new SolidColorBrush(Colors.Red);
                }
                else
                {
                    response5.Text = args.Result;
                }
            });
            c.DownloadStringAsync(new Uri("http://localhost:50350/handler1.ashx"));
        }

        private void CrossDomainClientStackNoPolicy(object sender, RoutedEventArgs e)
        {
            WebRequest.RegisterPrefix("http://", WebRequestCreator.ClientHttp);

            WebClient c = new WebClient();
            c.Headers[HttpRequestHeader.Authorization] = "Auth header from x-domain client-no policy";
            c.DownloadStringCompleted += ((s, args) =>
            {
                if (args.Error != null)
                {
                    response6.Text = args.Error.InnerException.Message;
                    response6.Foreground = new SolidColorBrush(Colors.Red);
                }
                else
                {
                    response6.Text = args.Result;
                }
            });
            c.DownloadStringAsync(new Uri("http://localhost:50350/handler1.ashx"));
        }
    }
}